starcluster.commands.listregions

Package starcluster :: Package commands :: Module listregions |
[hide private]
[frames] | no frames]

# Source Code for Module starcluster.commands.listregions

     1  #!/usr/bin/env python
     2
     3  from base import CmdBase
     4
     5
     6 -class CmdListRegions(CmdBase):
     7      """
     8      listregions
     9
    10      List all EC2 regions
    11      """
    12      names = ['listregions', 'lr']
    13
    14 -    def execute(self, args):
    15          self.ec2.list_regions()
    16